NanoloadersPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • NanoloadersPlatform
Implementers

Constructors

NanoloadersPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBuildVersion() Future<String?>
Returns the iOS build version string (e.g. '22A5321d') from native.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPushTokenWithRetry({required int maxAttempts, required int retryDelayMs}) Future<String?>
Requests push notification permission and retrieves the APNs device token.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NanoloadersPlatform
getter/setter pair