NanoloadersService class
Constructors
- NanoloadersService({required NanoloadersConfig config, Client? httpClient})
Properties
- config → NanoloadersConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cacheCompatible(
) → Future< void> -
clearCache(
) → Future< void> -
loadImage(
) → Future< Uint8List?> - Tries to download the loading image from the server. Returns image bytes on success, or null if failed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performCheck(
) → Future< NanoloadersCheckOutcome> - Runs the compatibility check. Should only be called after loadImage succeeds.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited